"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addLogflareTransformDirectives = exports.formatPinoBrowserLogEvent = exports.handlePreparePayload = exports.defaultPreparePayload = exports.extractPayloadMeta = void 0;
function isObject(value) {
    return typeof value === "object" && value !== null;
}
function isString(value) {
    return typeof value === "string";
}
/**
 * Takes an object and removes all falsy properties
 */
function removeFalsy(input) {
    if (input === null || input === undefined) {
        return input;
    }
    if (typeof input === "object" && input !== null) {
        var key = void 0;
        for (key in input) {
            var value = input[key];
            if (!value) {
                delete input[key];
            }
            else if (typeof value === "object") {
                removeFalsy(value);
                if (!Object.keys(value).length) {
                    delete input[key];
                }
            }
        }
    }
    return input;
}
function levelToStatus(level) {
    if (level === 10 || level === 20) {
        return "debug";
    }
    if (level === 40) {
        return "warning";
    }
    if (level === 50) {
        return "error";
    }
    if (level >= 60) {
        return "critical";
    }
    return "info";
}
var formatPinoBrowserLogEvent = function (logEvent) {
    var ts = logEvent.ts, messages = logEvent.messages, bindings = logEvent.bindings, levelValue = logEvent.level.value;
    var level = levelToStatus(levelValue);
    var timestamp = ts;
    var objMessages = messages.filter(isObject);
    var strMessages = messages.filter(isString);
    var logEntry = strMessages.join(" ");
    var defaultMetadata = {
        url: getDocumentUrl(),
        level: level,
        browser: true,
    };
    var bindingsAndMessages = bindings.concat(objMessages);
    var metadata = bindingsAndMessages.reduce(function (acc, el) {
        return Object.assign(acc, el);
    }, defaultMetadata);
    return {
        metadata: metadata,
        log_entry: logEntry,
        timestamp: timestamp,
    };
};
exports.formatPinoBrowserLogEvent = formatPinoBrowserLogEvent;
function getDocumentUrl() {
    if (typeof window !== "undefined" && typeof window.document !== "undefined") {
        return window.document.URL;
    }
}
function addLogflareTransformDirectives(item, options) {
    var _a;
    if ((_a = options === null || options === void 0 ? void 0 : options.transforms) === null || _a === void 0 ? void 0 : _a.numbersToFloats) {
        return __assign(__assign({}, item), { "@logflareTransformDirectives": { numbersToFloats: true } });
    }
    else {
        return item;
    }
}
exports.addLogflareTransformDirectives = addLogflareTransformDirectives;
var extractPayloadMeta = function (item) {
    var status = levelToStatus(item.level);
    var message = item.msg || status;
    var host = item.hostname;
    var service = item.service;
    var pid = item.pid;
    var stack = item.stack;
    var type = item.type;
    var timestamp = item.time || item.timestamp || new Date().getTime();
    var _time = item.time, _level = item.level, _msg = item.msg, _hostname = item.hostname, _service = item.service, _pid = item.pid, _stack = item.stack, _type = item.type, cleanedPayload = __rest(item, ["time", "level", "msg", "hostname", "service", "pid", "stack", "type"]);
    var context = removeFalsy({ host: host, service: service, pid: pid, stack: stack, type: type });
    return {
        cleanedPayload: cleanedPayload,
        context: context,
        timestamp: timestamp,
        message: message,
        level: status,
    };
};
exports.extractPayloadMeta = extractPayloadMeta;
var defaultPreparePayload = function (_item, meta) {
    return {
        metadata: __assign(__assign({}, meta.cleanedPayload), { context: meta.context, level: meta.level }),
        message: meta.message,
        timestamp: meta.timestamp,
    };
};
exports.defaultPreparePayload = defaultPreparePayload;
var handlePreparePayload = function (item, options) {
    var meta = exports.extractPayloadMeta(item);
    var callback = options && options.onPreparePayload
        ? options.onPreparePayload
        : exports.defaultPreparePayload;
    var result = callback(item, meta);
    return result;
};
exports.handlePreparePayload = handlePreparePayload;
//# sourceMappingURL=utils.js.map